@@ -4,16 +4,15 @@ OC.L10N.register(
     "Rename" : "Rename",
     "Move" : "Move",
     "Delete" : "Delete",
-    "Save" : "Save",
     "Cancel" : "Cancel",
-    "URL" : "Url",
+    "Title" : "Title",
+    "Link" : "Link",
     "Notes" : "Notes",
     "Owner" : "Owner",
     "Share link" : "Share link",
     "Allow editing" : "Дазволіць рэдагаванне",
     "Select" : "Select",
-    "Title" : "Title",
-    "Link" : "Link",
-    "Folder" : "Folder"
+    "Folder" : "Folder",
+    "Save" : "Save"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
