@@ -4,6 +4,7 @@ OC.L10N.register(
     "Bookmarks" : "Legosignaro",
     "No file provided for import" : "Neniu dosiero provizita por enporto",
     "Unsupported file type for import" : "Nesubtenita dosiertipo por enporto",
+    "Recent Bookmarks" : "Lastaj legosignoj",
     "A Bookmark manager for Nextcloud" : "Mastrumilo de legosignoj por Nextcloud",
     "Select bookmark" : "Elekti legosignon",
     "Details" : "Detaloj",
@@ -22,6 +23,7 @@ OC.L10N.register(
     "Enter a link" : "Entajpu ligilon",
     "Enter folder title" : "Entajpu titolon de la dosierujo",
     "Root folder" : "Radika dosierujo",
+    "Submit" : "Sendi",
     "Cancel" : "Nuligi",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Movo de %n dosierujo kaj kelkaj legosignoj","Movo de %n dosierujoj kaj kelkaj legosignoj"],
     "_Moving %n folder_::_Moving %n folders_" : ["Movo de %n dosierujo","Movo de %n dosierujoj"],
