@@ -9,18 +9,29 @@ OC.L10N.register(
     "%1$s deleted \"%2$s\"" : "„%2$s” נמחק על ידי %1$s",
     "Someone deleted \"%s\"" : "מישהו מחק את „%s”",
     "You created folder \"%s\"" : "יצרת את התיקייה „%s”",
+    "%1$s created folder \"%2$s\"" : "התיקייה „%2$s” נוצרה על ידי %1$s",
+    "Someone created folder \"%s\"" : "התיקייה „%s” נוצרה על ידי מישהו",
     "You moved folder \"%s\"" : "העברת את התיקייה „%s”",
+    "%1$s moved folder \"%2$s\"" : "התיקייה „%2$s” הועברה על ידי %1$s",
+    "Someone moved folder \"%s\"" : "התיקייה „%s” הועברה על ידי מישהו",
+    "You deleted folder \"%s\"" : "מחקת את התיקייה „%s”",
     "No file provided for import" : "לא סופק קובץ לייבוא",
     "Unsupported file type for import" : "סוג הקובץ לייבוא אינו נתמך",
     "Bookmarks shared by %s" : "סימניות שמשותפות על ידי %s",
     "Recent Bookmarks" : "סימניות אחרונות",
+    "Bookmark" : "סימנייה",
+    "Bookmark deleted" : "סימנייה נמחקה",
+    "Bookmark created" : "סימנייה נוצרה",
+    "Bookmark moved" : "סימנייה הועברה",
+    "Bookmark updated" : "סימנייה עודכנה",
+    "Create bookmark" : "יצירת סימנייה",
+    "Takes a link and adds it to your collection of bookmarks." : "לוקח קישור ומוסיף אותו לאוסף הסימניות שלך.",
     "A Bookmark manager for Nextcloud" : "מנהל סימניות ל־Nextcloud",
     "Select bookmark" : "בחירת סימנייה",
     "Details" : "פרטים",
     "Rename" : "שינוי שם",
     "Move" : "העברה",
     "Delete" : "מחיקה",
-    "Search" : "חיפוש",
     "Select one or more tags" : "יש לבחור תגית אחת או יותר",
     "New" : "חדש",
     "New bookmark" : "סימנייה חדשה",
@@ -33,24 +44,36 @@ OC.L10N.register(
     "Select all" : "בחר הכל",
     "Cancel selection" : "ביטול בחירה",
     "Selected {folders} folders and {bookmarks} bookmarks" : "נבחרו {folders} תיקיות ו־{bookmarks} סימניות",
+    "Do you really want to delete these items?" : "למחוק את הפריטים האלה?",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["סימנייה אחת נבחרה","%n סימניות נבחרו","%n סימניות נבחרו","%n סימניות נבחרו"],
     "_Selected %n folder_::_Selected %n folders_" : ["נבחרה תיקייה %n","נבחרו %n תיקיות","נבחרו %n תיקיות","נבחרו %n תיקיות"],
     "Enter a link" : "נא למלא קישור",
+    "Enter a title" : "נא למלא כותרת",
+    "No bookmarks found" : "לא נמצאו סימניות",
     "Select folder" : "בחירת תיקייה",
     "Enter folder title" : "נא למלא כותרת לתיקייה",
     "Shared by {user}" : "שותפה על ידי {user}",
+    "Do you really want to delete this folder?" : "למחוק את התיקייה הזאת?",
     "Root folder" : "תיקיית בסיס",
     "Submit" : "שליחה",
     "Cancel" : "ביטול",
+    "Deleting bookmarks" : "הסימניות נמחקות",
+    "Deleting selection" : "הבחירה נמחקת",
+    "Importing bookmarks" : "סימניות מיובאות",
+    "Moving selection" : "הבחירה מועברת",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["תיקייה אחת ומספר סימניות מועברות","%n תיקיות ומספר סימניות מועברות","%n תיקיות ומספר סימניות מועברות","%n תיקיות ומספר סימניות מועברות"],
     "_Moving %n folder_::_Moving %n folders_" : ["תיקייה אחת מועברת","%n תיקיות מועברות","%n תיקיות מועברות","%n תיקיות מועברות"],
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["סימנייה אחת מועברת","%n סימניות מועברות","%n סימניות מועברות","%n סימניות מועברות"],
     "All bookmarks" : "כל הסימניות",
     "Recent" : "אחרונים",
+    "Broken links" : "קישורים פגומים",
+    "Filter tags" : "סינון תגיות",
     "Untagged" : "ללא תגית",
     "{used} bookmarks of {available} available" : "{used} סימניות מתוך {available} זמינות",
+    "No archived bookmarks" : "אין סימניות בארכיון",
     "No bookmarks here" : "אין כאן סימניות",
     "Add a bookmark" : "הוספת סימנייה",
+    "Sync with your browser" : "סנכרון עם הדפדפן שלך",
     "Import" : "ייבוא",
     "Export" : "ייצוא",
     "Sorting" : "מיון",
@@ -58,6 +81,9 @@ OC.L10N.register(
     "Alphabetically" : "בסדר האלף-בית",
     "Most visited" : "הכי הרבה ביקורים",
     "Last modified" : "מועד שינוי אחרון",
+    "Custom order" : "סדר משלך",
+    "Archive path" : "נתיב הארכיון",
+    "Enter the path of a folder where bookmarked files should be stored" : "נא למלא את הנתיב לתיקייה שבה יישמרו הקבצים שיש סימניות שמפנות אליהם",
     "Client apps" : "יישומוני לקוח",
     "Also check out the collection of client apps that integrate with this app: " : "כדאי להציץ באוסף יישומוני הלקוח שמשתלבים עם היישומון הזה:",
     "Install web app" : "התקנת יישומון דפדפן",
@@ -69,6 +95,7 @@ OC.L10N.register(
     "Permanently remove all bookmarks from your account." : "הסרת כל הסימניות מהחשבון שלך לצמיתות.",
     "Delete all bookmarks" : "מחיקת כל הסימניות",
     "Do you really want to delete all your bookmarks?" : "למחוק את כל הסימניות שלך?",
+    "Please select \"Add to home screen\" in your browser menu" : "נא לבחור באפשרות „הוספה למסך הבית” בתפריט הדפדפן שלך",
     "Title" : "תפקיד",
     "Link" : "קישור",
     "Creation date" : "מועד יצירה",
@@ -94,6 +121,8 @@ OC.L10N.register(
     "You can either sign up for free at screeenly.com or setup your own server." : "ניתן להירשם בחינם בכתובת screeenly.com או להקים שרת משלך.",
     "Screeenly API URL" : "כתובת ה־API של Screeenly",
     "Screeenly API key" : "מפתח ה־API של Screeenly",
+    "ScreenshotMachine" : "ScreenshotMachine",
+    "ScreenshotMachine API key" : "מפתח ה־API של ScreenshotMachine",
     "Privacy" : "פרטיות",
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "תכנית הסימניות תנסה לגשת אל האתרים שהוספת כדי להוסיף עליהן מידע אוטומטית.",
     "Enable accessing and collecting information from the web pages you add" : "הפעלת גישה ואיסוף של מידע מהאתרים שהוספת.",
