@@ -4,15 +4,14 @@ OC.L10N.register(
     "Rename" : "Rename",
     "Move" : "Move",
     "Delete" : "حذف کریں",
-    "Save" : "حفظ",
     "Cancel" : "منسوخ کریں",
-    "URL" : "یو ار ایل",
+    "Title" : "عنوان",
+    "Link" : "Link",
     "Notes" : "Notes",
     "Owner" : "Owner",
     "Share link" : "اشتراک لنک",
     "Select" : "Select",
-    "Title" : "عنوان",
-    "Link" : "Link",
-    "Folder" : "Folder"
+    "Folder" : "Folder",
+    "Save" : "حفظ"
 },
 "nplurals=2; plural=(n != 1);");
