@@ -1,4 +1,9 @@
 <?php
+/*
+ * Copyright (c) 2020. The Nextcloud Bookmarks contributors.
+ *
+ * This file is licensed under the Affero General Public License version 3 or later. See the COPYING file.
+ */
 
 namespace OCA\Bookmarks\Service;
 
@@ -46,6 +51,10 @@ class HtmlImporter {
 	 * @var TreeMapper
 	 */
 	private $treeMapper;
+	/**
+	 * @var TreeCacheManager
+	 */
+	private $hashManager;
 
 	/**
 	 * ImportService constructor.
@@ -53,22 +62,28 @@ class HtmlImporter {
 	 * @param BookmarkMapper $bookmarkMapper
 	 * @param FolderMapper $folderMapper
 	 * @param TagMapper $tagMapper
+	 * @param TreeMapper $treeMapper
 	 * @param BookmarksParser $bookmarksParser
+	 * @param TreeCacheManager $hashManager
 	 */
-	public function __construct(BookmarkMapper $bookmarkMapper, FolderMapper $folderMapper, TagMapper $tagMapper, TreeMapper $treeMapper, BookmarksParser $bookmarksParser) {
+	public function __construct(BookmarkMapper $bookmarkMapper, FolderMapper $folderMapper, TagMapper $tagMapper, TreeMapper $treeMapper, BookmarksParser $bookmarksParser, \OCA\Bookmarks\Service\TreeCacheManager $hashManager) {
 		$this->bookmarkMapper = $bookmarkMapper;
 		$this->folderMapper = $folderMapper;
 		$this->tagMapper = $tagMapper;
 		$this->treeMapper = $treeMapper;
 		$this->bookmarksParser = $bookmarksParser;
+		$this->hashManager = $hashManager;
 	}
 
 	/**
 	 * @brief Import Bookmarks from html formatted file
+	 *
 	 * @param int $userId
-	 * @param string $file Content to import
-	 * @param int $rootFolder
+	 * @param string $file
+	 * @param int|null $rootFolder
+	 *
 	 * @return array
+	 *
 	 * @throws DoesNotExistException
 	 * @throws MultipleObjectsReturnedException
 	 * @throws UnauthorizedAccessError
@@ -83,20 +98,26 @@ class HtmlImporter {
 
 	/**
 	 * @brief Import Bookmarks from html
+	 *
 	 * @param int $userId
 	 * @param string $content
 	 * @param int|null $rootFolderId
-	 * @return array
+	 *
+	 * @return (array|mixed|string)[][]
+	 *
 	 * @throws AlreadyExistsError
 	 * @throws DoesNotExistException
 	 * @throws HtmlParseError
 	 * @throws MultipleObjectsReturnedException
 	 * @throws UnauthorizedAccessError
 	 * @throws UserLimitExceededError
+	 *
+	 * @psalm-return array{imported: list<array>, errors: array<array-key, mixed|string>}
 	 */
 	public function import($userId, string $content, int $rootFolderId = null): array {
 		$imported = [];
 		$errors = [];
+
 		if ($rootFolderId === null) {
 			$rootFolder = $this->folderMapper->findRootFolder($userId);
 		} else {
@@ -105,7 +126,12 @@ class HtmlImporter {
 				throw new UnauthorizedAccessError('Not allowed to access folder ' . $rootFolder->getId());
 			}
 		}
+
 		$this->bookmarksParser->parse($content, false);
+
+		// Disable invalidation, since we're going to add a bunch of new data to the tree at a single point
+		$this->hashManager->setInvalidationEnabled(false);
+
 		foreach ($this->bookmarksParser->currentFolder['children'] as $folder) {
 			$imported[] = $this->importFolder($userId, $folder, $rootFolder->getId(), $errors);
 		}
@@ -118,26 +144,36 @@ class HtmlImporter {
 			}
 			$imported[] = ['type' => 'bookmark', 'id' => $bm->getId(), 'title' => $bookmark['title'], 'url' => $bookmark['href']];
 		}
+
+		$this->hashManager->setInvalidationEnabled(true);
+		$this->hashManager->invalidateFolder($rootFolder->getId());
+
 		return ['imported' => $imported, 'errors' => $errors];
 	}
 
 	/**
-	 * @param int $userId
+	 * @param string $userId
 	 * @param array $folderParams
 	 * @param int $parentId
 	 * @param array $errors
-	 * @return array
+	 * @param int|null $index
+	 *
+	 * @return (array[]|int|mixed|string)[]
+	 *
 	 * @throws DoesNotExistException
 	 * @throws MultipleObjectsReturnedException
 	 * @throws UnauthorizedAccessError
 	 * @throws AlreadyExistsError
 	 * @throws UserLimitExceededError
 	 * @throws UnsupportedOperation
+	 *
+	 * @psalm-return array{type: string, id: int, title: mixed, children: list<array>}
 	 */
-	private function importFolder($userId, array $folderParams, int $parentId, &$errors = [], $index = null): array {
+	private function importFolder(string $userId, array $folderParams, int $parentId, &$errors = [], $index = null): array {
 		$folder = new Folder();
 		$folder->setUserId($userId);
 		$folder->setTitle($folderParams['title']);
+		/** @var Folder $folder */
 		$folder = $this->folderMapper->insert($folder);
 		$this->treeMapper->move(TreeMapper::TYPE_FOLDER, $folder->getId(), $parentId, $index);
 		$newFolder = ['type' => 'folder', 'id' => $folder->getId(), 'title' => $folderParams['title'], 'children' => []];
@@ -158,17 +194,17 @@ class HtmlImporter {
 	}
 
 	/**
-	 * @param int $userId
+	 * @param string $userId
 	 * @param int $folderId
 	 * @param array $bookmark
-	 * @param null $index
+	 * @param null|int $index
 	 * @return Bookmark|Entity
+	 * @throws UrlParseError
 	 * @throws AlreadyExistsError
 	 * @throws UnsupportedOperation
-	 * @throws UrlParseError
 	 * @throws UserLimitExceededError
 	 */
-	private function importBookmark($userId, int $folderId, array $bookmark, $index = null) {
+	private function importBookmark(string $userId, int $folderId, array $bookmark, $index = null) {
 		$bm = new Bookmark();
 		$bm->setUserId($userId);
 		$bm->setUrl($bookmark['href']);
@@ -179,6 +215,7 @@ class HtmlImporter {
 		}
 
 		// insert bookmark
+		/** @var Bookmark $bm */
 		$bm = $this->bookmarkMapper->insertOrUpdate($bm);
 		// add to folder
 		$this->treeMapper->addToFolders(TreeMapper::TYPE_BOOKMARK, $bm->getId(), [$folderId], $index);
