@@ -10,7 +10,7 @@ import router from './router'
 import store from './store/'
 import AppGlobal from './mixins/AppGlobal'
 import { subscribe } from '@nextcloud/event-bus'
-// import { generateUrl } from '@nextcloud/router'
+import { generateUrl } from '@nextcloud/router'
 
 Vue.mixin(AppGlobal)
 Vue.directive('tooltip', Tooltip)
@@ -30,7 +30,7 @@ const BookmarksApp = (global.Bookmarks = new Vue({
 	render: h => h(App),
 }))
 
-/* if ('serviceWorker' in navigator) {
+if ('serviceWorker' in navigator) {
 	navigator.serviceWorker.register(generateUrl('/apps/bookmarks/service-worker.js'))
 		.then(() => {
 			console.info('ServiceWorker registered')
@@ -43,6 +43,6 @@ const BookmarksApp = (global.Bookmarks = new Vue({
 	})
 } else {
 	console.warn('ServiceWorker not supported')
-} */
+}
 
 export default BookmarksApp
